@@ -88,6 +88,7 @@
 //! # }
 //! ```
 
+use env_name_str::EnvNameString;
 use shared_child::SharedChild;
 use shared_thread::SharedThread;
 use std::collections::HashMap;
@@ -106,6 +107,13 @@ use std::os::unix::prelude::*;
 #[cfg(windows)]
 use std::os::windows::prelude::*;
 
+#[cfg(not(windows))]
+use std::os::fd::IntoRawFd as IntoRawFdOrHandle;
+#[cfg(windows)]
+use std::os::windows::io::IntoRawHandle as IntoRawFdOrHandle;
+
+mod env_name_str;
+
 /// Unix-specific extensions to duct, for sending signals.
 #[cfg(unix)]
 pub mod unix;
@@ -175,15 +183,14 @@ macro_rules! cmd {
     };
 }
 
-/// The central objects in Duct, Expressions are created with
-/// [`cmd`](fn.cmd.html) or [`cmd!`](macro.cmd.html), combined with
-/// [`pipe`](struct.Expression.html#method.pipe), and finally executed with
-/// [`run`](struct.Expression.html#method.run),
-/// [`read`](struct.Expression.html#method.read),
+/// The central objects in Duct, created with
+/// [`cmd`](fn.cmd.html) or [`cmd!`](macro.cmd.html).
+///
+/// Expressions can be combined with [`pipe`](struct.Expression.html#method.pipe) and executed with
+/// [`run`](struct.Expression.html#method.run), [`read`](struct.Expression.html#method.read),
 /// [`start`](struct.Expression.html#method.start), or
-/// [`reader`](struct.Expression.html#method.reader). They also support several
-/// methods to control their execution, like
-/// [`stdin_bytes`](struct.Expression.html#method.stdin_bytes),
+/// [`reader`](struct.Expression.html#method.reader). There are many other methods to control their
+/// execution, like [`stdin_bytes`](struct.Expression.html#method.stdin_bytes),
 /// [`stdout_capture`](struct.Expression.html#method.stdout_capture),
 /// [`env`](struct.Expression.html#method.env), and
 /// [`unchecked`](struct.Expression.html#method.unchecked).
@@ -202,13 +209,13 @@ macro_rules! cmd {
 /// # use duct::cmd;
 /// # fn main() -> std::io::Result<()> {
 /// // Only suppress stderr on the left side.
-/// cmd!("foo").stderr_null().pipe(cmd!("bar")).run()?;
+/// cmd!("foo").stderr_null().pipe(cmd!("bar")).run()?; // foo 2>/dev/null | bar
 ///
 /// // Only suppress stderr on the right side.
-/// cmd!("foo").pipe(cmd!("bar").stderr_null()).run()?;
+/// cmd!("foo").pipe(cmd!("bar").stderr_null()).run()?; // foo | bar 2>/dev/null
 ///
 /// // Suppress stderr on both sides.
-/// cmd!("foo").pipe(cmd!("bar")).stderr_null().run()?;
+/// cmd!("foo").pipe(cmd!("bar")).stderr_null().run()?; // (foo | bar) 2>/dev/null
 /// # Ok(())
 /// # }
 /// ```
@@ -451,13 +458,8 @@ impl Expression {
     /// # }
     /// # }
     /// ```
-    #[cfg(not(windows))]
-    pub fn stdin_file<T: IntoRawFd>(&self, file: T) -> Expression {
-        Self::new(Io(StdinFile(into_file(file)), self.clone()))
-    }
-    #[cfg(windows)]
-    pub fn stdin_file<T: IntoRawHandle>(&self, file: T) -> Expression {
-        Self::new(Io(StdinFile(into_file(file)), self.clone()))
+    pub fn stdin_file<T: IntoRawFdOrHandle>(&self, file: T) -> Expression {
+        Self::new(Io(StdinFile(owned_from_raw(file)), self.clone()))
     }
 
     /// Use `/dev/null` (or `NUL` on Windows) as input for an expression.
@@ -518,13 +520,8 @@ impl Expression {
     /// # }
     /// # }
     /// ```
-    #[cfg(not(windows))]
-    pub fn stdout_file<T: IntoRawFd>(&self, file: T) -> Expression {
-        Self::new(Io(StdoutFile(into_file(file)), self.clone()))
-    }
-    #[cfg(windows)]
-    pub fn stdout_file<T: IntoRawHandle>(&self, file: T) -> Expression {
-        Self::new(Io(StdoutFile(into_file(file)), self.clone()))
+    pub fn stdout_file<T: IntoRawFdOrHandle>(&self, file: T) -> Expression {
+        Self::new(Io(StdoutFile(owned_from_raw(file)), self.clone()))
     }
 
     /// Use `/dev/null` (or `NUL` on Windows) as output for an expression.
@@ -638,13 +635,8 @@ impl Expression {
     /// # }
     /// # }
     /// ```
-    #[cfg(not(windows))]
-    pub fn stderr_file<T: IntoRawFd>(&self, file: T) -> Expression {
-        Self::new(Io(StderrFile(into_file(file)), self.clone()))
-    }
-    #[cfg(windows)]
-    pub fn stderr_file<T: IntoRawHandle>(&self, file: T) -> Expression {
-        Self::new(Io(StderrFile(into_file(file)), self.clone()))
+    pub fn stderr_file<T: IntoRawFdOrHandle>(&self, file: T) -> Expression {
+        Self::new(Io(StderrFile(owned_from_raw(file)), self.clone()))
     }
 
     /// Use `/dev/null` (or `NUL` on Windows) as error output for an expression.
@@ -782,10 +774,7 @@ impl Expression {
         T: Into<OsString>,
         U: Into<OsString>,
     {
-        Self::new(Io(
-            Env(canonicalize_env_var_name(name.into()), val.into()),
-            self.clone(),
-        ))
+        Self::new(Io(Env(EnvNameString::from(name), val.into()), self.clone()))
     }
 
     /// Remove a variable from the expression's environment.
@@ -814,10 +803,7 @@ impl Expression {
     where
         T: Into<OsString>,
     {
-        Self::new(Io(
-            EnvRemove(canonicalize_env_var_name(name.into())),
-            self.clone(),
-        ))
+        Self::new(Io(EnvRemove(EnvNameString::from(name)), self.clone()))
     }
 
     /// Set the expression's entire environment, from a collection of
@@ -852,7 +838,7 @@ impl Expression {
     {
         let env_map = name_vals
             .into_iter()
-            .map(|(k, v)| (canonicalize_env_var_name(k.into()), v.into()))
+            .map(|(k, v)| (EnvNameString::from(k), v.into()))
             .collect();
         Self::new(Io(FullEnv(env_map), self.clone()))
     }
@@ -952,7 +938,7 @@ impl<'a> From<&'a Expression> for Expression {
     }
 }
 
-/// A handle to a running expression, returned by the
+/// A handle to a running [`Expression`], returned by the
 /// [`start`](struct.Expression.html#method.start) method.
 ///
 /// Calling `start` followed by
@@ -979,50 +965,58 @@ pub struct Handle {
 }
 
 impl Handle {
-    /// Wait for the running expression to finish, and return a reference to its
+    /// Wait for the running [`Expression`] to finish, and return a reference to its
     /// [`std::process::Output`](https://doc.rust-lang.org/std/process/struct.Output.html).
-    /// Multiple threads may wait at the same time.
+    /// Multiple threads may wait at the same time, and waiting more than once returns the same
+    /// output again.
     ///
     /// # Errors
     ///
     /// In addition to all the IO errors possible with
-    /// [`std::process::Child`](https://doc.rust-lang.org/std/process/struct.Child.html),
-    /// `wait` will return an
-    /// [`ErrorKind::Other`](https://doc.rust-lang.org/std/io/enum.ErrorKind.html)
-    /// IO error if child returns a non-zero exit status. To suppress this
-    /// error and return an `Output` even when the exit status is non-zero, use
-    /// the [`unchecked`](struct.Expression.html#method.unchecked) method.
+    /// [`std::process::Child`](https://doc.rust-lang.org/std/process/struct.Child.html), `wait`
+    /// will return an [`ErrorKind::Other`](https://doc.rust-lang.org/std/io/enum.ErrorKind.html)
+    /// IO error if the child returns a non-zero exit status. To suppress this error and return an
+    /// `Output` even when the exit status is non-zero, use the
+    /// [`unchecked`](struct.Expression.html#method.unchecked) method.
     pub fn wait(&self) -> io::Result<&Output> {
-        // Await the children and any threads that are reading their output.
-        // Another caller may already have done this.
-        let (expression_status, output) = wait_on_handle_and_output(self, WaitMode::Blocking)?
-            .expect("blocking wait shouldn't return None");
-        // If the child returned a "checked" non-zero exit status, make that an error.
-        if expression_status.is_checked_error() {
-            return Err(io::Error::new(
-                io::ErrorKind::Other,
-                expression_status.message(),
-            ));
-        }
-        Ok(output)
+        wait_on_handle_and_output(self, WaitMode::Blocking)?;
+        self.try_wait().transpose().expect("already exited")
     }
 
-    /// Check whether the running expression is finished. If it is, return a
-    /// reference to its
+    /// Same as [`wait`][Self::wait], but with a timeout. If the running [`Expression`] finishes
+    /// within the timeout (or if it's already finished), return a reference to its
     /// [`std::process::Output`](https://doc.rust-lang.org/std/process/struct.Output.html).
-    /// If it's still running, return `Ok(None)`.
+    /// Otherwise, return `Ok(None)`.
     ///
     /// # Errors
     ///
-    /// In addition to all the IO errors possible with
-    /// [`std::process::Child`](https://doc.rust-lang.org/std/process/struct.Child.html),
-    /// `try_wait` will return an
-    /// [`ErrorKind::Other`](https://doc.rust-lang.org/std/io/enum.ErrorKind.html)
-    /// IO error if child returns a non-zero exit status. To suppress this
-    /// error and return an `Output` even when the exit status is non-zero, use
-    /// the [`unchecked`](struct.Expression.html#method.unchecked) method.
+    /// Same as [`wait`][Self::wait].
+    #[cfg(feature = "timeout")]
+    pub fn wait_timeout(&self, timeout: std::time::Duration) -> io::Result<Option<&Output>> {
+        let deadline = std::time::Instant::now() + timeout;
+        self.wait_deadline(deadline)
+    }
+
+    /// Same as [`wait_timeout`][Self::wait_timeout], but with a deadline instead of a timeout.
+    ///
+    /// # Errors
+    ///
+    /// Same as [`wait`][Self::wait].
+    #[cfg(feature = "timeout")]
+    pub fn wait_deadline(&self, deadline: std::time::Instant) -> io::Result<Option<&Output>> {
+        wait_on_handle_and_output(self, WaitMode::Deadline(deadline))?;
+        self.try_wait()
+    }
+
+    /// Check whether the running [`Expression`] has already finished. If it has, return a
+    /// reference to its
+    /// [`std::process::Output`](https://doc.rust-lang.org/std/process/struct.Output.html).
+    /// Otherwise, return `Ok(None)`.
+    ///
+    /// # Errors
+    ///
+    /// Same as [`wait`][Self::wait].
     pub fn try_wait(&self) -> io::Result<Option<&Output>> {
-        // Check whether child processes and IO threads are finished.
         let Some((expression_status, output)) =
             wait_on_handle_and_output(self, WaitMode::NonBlocking)?
         else {
@@ -1038,30 +1032,21 @@ impl Handle {
         Ok(Some(output))
     }
 
-    /// Wait for the running expression to finish, and then return a
-    /// [`std::process::Output`](https://doc.rust-lang.org/std/process/struct.Output.html)
-    /// object containing the results, including any captured output. This
-    /// consumes the `Handle`. Calling
-    /// [`start`](struct.Expression.html#method.start) followed by
-    /// `into_output` is equivalent to
-    /// [`run`](struct.Expression.html#method.run).
+    /// Same as [`wait`][Self::wait], but consume the `Handle` and return its
+    /// [`std::process::Output`](https://doc.rust-lang.org/std/process/struct.Output.html) by
+    /// value. Calling [`start`](struct.Expression.html#method.start) followed by `into_output` is
+    /// equivalent to [`run`](struct.Expression.html#method.run).
     ///
     /// # Errors
     ///
-    /// In addition to all the IO errors possible with
-    /// [`std::process::Child`](https://doc.rust-lang.org/std/process/struct.Child.html),
-    /// `into_output` will return an
-    /// [`ErrorKind::Other`](https://doc.rust-lang.org/std/io/enum.ErrorKind.html)
-    /// IO error if child returns a non-zero exit status. To suppress this
-    /// error and return an `Output` even when the exit status is non-zero, use
-    /// the [`unchecked`](struct.Expression.html#method.unchecked) method.
+    /// Same as [`wait`][Self::wait].
     pub fn into_output(self) -> io::Result<Output> {
         self.wait()?;
         let (_, output) = self.result.into_inner().expect("result missing");
         Ok(output)
     }
 
-    /// Kill all the child processes in the running expression.
+    /// Kill all the child processes in the running [`Expression`].
     ///
     /// Note that as with
     /// [`std::process::Child::kill`](https://doc.rust-lang.org/beta/std/process/struct.Child.html#method.kill),
@@ -1072,9 +1057,12 @@ impl Handle {
     /// for an extensive discussion of this behavior.
     ///
     /// This method does not wait on the child processes to exit. Calling [`wait`][Handle::wait]
-    /// after `kill` almost always returns quickly, but there are edge cases where it might not.
-    /// One case is if a child process is blocked reading an unresponsive FUSE filesystem. Another
-    /// is if a child process is paused by a debugger.
+    /// after `kill` usually returns quickly, but there are edge cases where it might not. The most
+    /// common case is if a grandchild process has inherited one or more of the child's
+    /// stdin/stdout/stderr pipes, and a worker thread related to
+    /// [`stdin_bytes`][Expression::stdin_bytes]/[`stdout_capture][Expression::stdout_capture]/[`stderr_capture][Expression::stderr_capture]
+    /// is still running. The kill signal might also be delayed if the child is blocked reading an
+    /// unresponsive FUSE filesystem, or paused by a debugger.
     pub fn kill(&self) -> io::Result<()> {
         self.inner.kill()
     }
@@ -1360,9 +1348,9 @@ impl PipeHandle {
         let (reader, writer) = os_pipe::pipe()?;
         // dup'ing stdin/stdout isn't strictly necessary, but no big deal
         let mut left_context = context.try_clone()?;
-        left_context.stdout = IoValue::Handle(into_file(writer));
+        left_context.stdout = IoValue::Handle(writer.into());
         let mut right_context = context;
-        right_context.stdin = IoValue::Handle(into_file(reader));
+        right_context.stdin = IoValue::Handle(reader.into());
         let left_handle = left.0.start(left_context)?;
         // The left side has already started. If we fail to start the right
         // side, ChildHandle::drop will clean it up one way or another. Note
@@ -1447,7 +1435,7 @@ fn start_io(
             )?)));
         }
         StdinPath(p) => {
-            context.stdin = IoValue::Handle(File::open(p)?);
+            context.stdin = IoValue::Handle(File::open(p)?.into());
         }
         StdinFile(f) => {
             context.stdin = IoValue::Handle(f.try_clone()?);
@@ -1456,7 +1444,7 @@ fn start_io(
             context.stdin = IoValue::Null;
         }
         StdoutPath(p) => {
-            context.stdout = IoValue::Handle(File::create(p)?);
+            context.stdout = IoValue::Handle(File::create(p)?.into());
         }
         StdoutFile(f) => {
             context.stdout = IoValue::Handle(f.try_clone()?);
@@ -1465,13 +1453,13 @@ fn start_io(
             context.stdout = IoValue::Null;
         }
         StdoutCapture => {
-            context.stdout = IoValue::Handle(into_file(context.stdout_capture.write_pipe()?));
+            context.stdout = IoValue::Handle(context.stdout_capture.write_pipe()?.into());
         }
         StdoutToStderr => {
             context.stdout = context.stderr.try_clone()?;
         }
         StderrPath(p) => {
-            context.stderr = IoValue::Handle(File::create(p)?);
+            context.stderr = IoValue::Handle(File::create(p)?.into());
         }
         StderrFile(f) => {
             context.stderr = IoValue::Handle(f.try_clone()?);
@@ -1480,7 +1468,7 @@ fn start_io(
             context.stderr = IoValue::Null;
         }
         StderrCapture => {
-            context.stderr = IoValue::Handle(into_file(context.stderr_capture.write_pipe()?));
+            context.stderr = IoValue::Handle(context.stderr_capture.write_pipe()?.into());
         }
         StderrToStdout => {
             context.stderr = context.stdout.try_clone()?;
@@ -1492,6 +1480,10 @@ fn start_io(
             context.dir = Some(p.clone());
         }
         Env(name, val) => {
+            // Note that HashMap::insert overwrites a preexisting *value*, but not a preexisting
+            // *key*. We rely on this to match platform behavior on Windows, where the original
+            // casing of a variable name is preserved even if an equivalent name with a different
+            // casing is added.
             context.env.insert(name.clone(), val.clone());
         }
         EnvRemove(name) => {
@@ -1524,7 +1516,7 @@ impl StdinBytesHandle {
         input: Arc<Vec<u8>>,
     ) -> io::Result<StdinBytesHandle> {
         let (reader, mut writer) = os_pipe::pipe()?;
-        context.stdin = IoValue::Handle(into_file(reader));
+        context.stdin = IoValue::Handle(reader.into());
         let inner_handle = expression.0.start(context)?;
         let writer_thread = SharedThread::spawn(move || {
             // Broken pipe errors are expected here. Suppress them.
@@ -1541,10 +1533,12 @@ impl StdinBytesHandle {
 
     fn wait(&self, mode: WaitMode) -> io::Result<Option<ExpressionStatus>> {
         let maybe_status = self.inner_handle.wait(mode)?;
-        // Even if the child has exited, grandchild processes might still be reading from the
-        // writer thread. If the wait mode is Blocking, mode.maybe_join_io_thread will wait for
-        // the writer thread to finish (i.e. it will never return Ok(false)). Otherwise, if the IO
-        // thread is still
+        // Even if the child has exited, some grandchild process might keep this pipe open and keep
+        // reading from it. It's tempting not to wait for this IO thread at all and just let it run
+        // in the background, but that wouldn't work if the current process exited. (When the main
+        // function returns and the process exits, all background threads are terminated.) Waiting
+        // on this Handle might be the last thing the caller does in main, who knows, so for
+        // correctness a blocking waiter does need to wait until this IO thread is finished.
         let io_finished = mode.maybe_join_io_thread(&self.writer_thread)?.is_some();
         if !io_finished {
             return Ok(None);
@@ -1561,23 +1555,23 @@ impl StdinBytesHandle {
 enum IoExpressionInner {
     StdinBytes(Arc<Vec<u8>>),
     StdinPath(PathBuf),
-    StdinFile(File),
+    StdinFile(FdOrHandle),
     StdinNull,
     StdoutPath(PathBuf),
-    StdoutFile(File),
+    StdoutFile(FdOrHandle),
     StdoutNull,
     StdoutCapture,
     StdoutToStderr,
     StderrPath(PathBuf),
-    StderrFile(File),
+    StderrFile(FdOrHandle),
     StderrNull,
     StderrCapture,
     StderrToStdout,
     StdoutStderrSwap,
     Dir(PathBuf),
-    Env(OsString, OsString),
-    EnvRemove(OsString),
-    FullEnv(HashMap<OsString, OsString>),
+    Env(EnvNameString, OsString),
+    EnvRemove(EnvNameString),
+    FullEnv(HashMap<EnvNameString, OsString>),
     Unchecked,
     BeforeSpawn(BeforeSpawnHook),
 }
@@ -1621,7 +1615,7 @@ struct IoContext<'a> {
     stdout_capture: &'a OutputCaptureContext,
     stderr_capture: &'a OutputCaptureContext,
     dir: Option<PathBuf>,
-    env: HashMap<OsString, OsString>,
+    env: HashMap<EnvNameString, OsString>,
     before_spawn_hooks: Vec<BeforeSpawnHook>,
 }
 
@@ -1638,7 +1632,7 @@ impl<'a> IoContext<'a> {
             stdout_capture,
             stderr_capture,
             dir: None,
-            env: std::env::vars_os().collect(),
+            env: std::env::vars_os().map(|(k, v)| (k.into(), v)).collect(),
             before_spawn_hooks: Vec::new(),
         }
     }
@@ -1663,10 +1657,7 @@ enum IoValue {
     ParentStdout,
     ParentStderr,
     Null,
-    // We store all handles as File, even when they're e.g. anonymous pipes,
-    // using the into_file() conversion below. The File type is a very thin
-    // wrapper around the raw handle, but it gives us try_clone() and drop().
-    Handle(File),
+    Handle(FdOrHandle),
 }
 
 impl IoValue {
@@ -1691,24 +1682,6 @@ impl IoValue {
     }
 }
 
-// We would rather convert an fd-owning object directly into a
-// std::process::Stdio, since all you can do with that is give it to a
-// std::process::Command. Unfortunately, Stdio doesn't provide a try_clone
-// method, and we need that in order to pass the object to multiple children.
-// As a workaround, convert the object to a std::fs::File. All we will use this
-// File for is try_clone and Into<Stdio>, which should be sound on any type of
-// descriptor. (Some types will lead to an error, like a TcpStream, but that's
-// not unsound.) If we discover any unsound cases, we might have to replace
-// this with a new trait.
-#[cfg(not(windows))]
-fn into_file<T: IntoRawFd>(handle: T) -> File {
-    unsafe { File::from_raw_fd(handle.into_raw_fd()) }
-}
-#[cfg(windows)]
-fn into_file<T: IntoRawHandle>(handle: T) -> File {
-    unsafe { File::from_raw_handle(handle.into_raw_handle()) }
-}
-
 // This struct keeps track of a child exit status, whether or not it's been
 // unchecked(), and what the command was that gave it (for error messages).
 #[derive(Clone, Debug)]
@@ -1879,8 +1852,13 @@ fn clone_io_error(error: &io::Error) -> io::Error {
 
 #[derive(Clone, Copy, Debug)]
 enum WaitMode {
-    Blocking,    // like .wait(), wait until everything is finished
-    NonBlocking, // like .try_wait(), never block
+    // block until everything is finished, as in .wait()
+    Blocking,
+    // don't block at all, as in .try_wait()
+    NonBlocking,
+    // block with a deadline, as in .wait_deadline() or .wait_timeout()
+    #[cfg(feature = "timeout")]
+    Deadline(std::time::Instant),
 }
 
 impl WaitMode {
@@ -1888,6 +1866,8 @@ impl WaitMode {
         match self {
             WaitMode::Blocking => child.wait().map(Some),
             WaitMode::NonBlocking => child.try_wait(),
+            #[cfg(feature = "timeout")]
+            WaitMode::Deadline(deadline) => child.wait_deadline(deadline),
         }
     }
 
@@ -1907,28 +1887,16 @@ impl WaitMode {
                 Some(Err(e)) => Err(clone_io_error(e)),
                 None => Ok(None),
             },
+            #[cfg(feature = "timeout")]
+            WaitMode::Deadline(deadline) => match io_thread.join_deadline(deadline) {
+                Some(Ok(val)) => Ok(Some(val)),
+                Some(Err(e)) => Err(clone_io_error(e)),
+                None => Ok(None),
+            },
         }
     }
 }
 
-#[cfg(windows)]
-fn canonicalize_env_var_name(name: OsString) -> OsString {
-    // On Windows, because env vars are case-insensitive, we uppercase all env
-    // var names. That makes assignments and deletions in our internal map work
-    // the same way they would on the real environment.
-    match name.into_string() {
-        Ok(name) => name.to_uppercase().into(),
-        // If the name isn't valid Unicode then just leave it as is.
-        Err(name) => name,
-    }
-}
-
-#[cfg(not(windows))]
-fn canonicalize_env_var_name(name: OsString) -> OsString {
-    // No-op on all other platforms.
-    name
-}
-
 type ReaderThread = SharedThread<io::Result<Vec<u8>>>;
 
 #[derive(Debug)]
@@ -2112,5 +2080,22 @@ impl Read for ReaderHandle {
     }
 }
 
+#[cfg(not(windows))]
+type FdOrHandle = OwnedFd;
+#[cfg(windows)]
+type FdOrHandle = OwnedHandle;
+
+// Without these conversions this crate could be 100% safe code, so this is kind of a shame, but I
+// don't want to change the trait bounds on stdin_file/stdout_file/stderr_file. There are types
+// that implement IntoRawFd but not Into<OwnedFd>, including RawFd itself.
+#[cfg(not(windows))]
+fn owned_from_raw(raw: impl IntoRawFd) -> OwnedFd {
+    unsafe { OwnedFd::from_raw_fd(raw.into_raw_fd()) }
+}
+#[cfg(windows)]
+fn owned_from_raw(raw: impl IntoRawHandle) -> OwnedHandle {
+    unsafe { OwnedHandle::from_raw_handle(raw.into_raw_handle()) }
+}
+
 #[cfg(test)]
 mod test;
