@@ -64,11 +64,7 @@ use hashbrown::hash_table;
 /// # }
 /// ```
 #[derive(Clone)]
-pub struct IdHashMap<
-    T: IdHashItem,
-    S = DefaultHashBuilder,
-    A: Allocator = Global,
-> {
+pub struct IdHashMap<T, S = DefaultHashBuilder, A: Allocator = Global> {
     pub(super) items: ItemSet<T, A>,
     tables: IdHashMapTables<S, A>,
 }
@@ -115,7 +111,7 @@ impl<T: IdHashItem> IdHashMap<T> {
     /// ```
     #[inline]
     pub fn new() -> Self {
-        Self { items: ItemSet::default(), tables: IdHashMapTables::default() }
+        Self { items: ItemSet::new(), tables: IdHashMapTables::default() }
     }
 
     /// Creates a new `IdHashMap` with the given capacity.
@@ -184,14 +180,10 @@ impl<T: IdHashItem, S: Clone + BuildHasher> IdHashMap<T, S> {
     /// let map: IdHashMap<Item, _> = IdHashMap::with_hasher(hasher);
     /// assert!(map.is_empty());
     /// ```
-    pub fn with_hasher(hasher: S) -> Self {
+    pub const fn with_hasher(hasher: S) -> Self {
         Self {
-            items: ItemSet::default(),
-            tables: IdHashMapTables::with_capacity_and_hasher_in(
-                0,
-                hasher,
-                global_alloc(),
-            ),
+            items: ItemSet::new(),
+            tables: IdHashMapTables::with_hasher_in(hasher, global_alloc()),
         }
     }
 
@@ -368,10 +360,8 @@ impl<T: IdHashItem, S: Clone + BuildHasher, A: Clone + Allocator>
     /// ```
     pub fn with_hasher_in(hasher: S, alloc: A) -> Self {
         Self {
-            items: ItemSet::with_capacity_in(0, alloc.clone()),
-            tables: IdHashMapTables::with_capacity_and_hasher_in(
-                0, hasher, alloc,
-            ),
+            items: ItemSet::new_in(alloc.clone()),
+            tables: IdHashMapTables::with_hasher_in(hasher, alloc),
         }
     }
 
